Discover Packages
github.com/Molsbee/mock-server
model
package
Version:
v0.0.0-...-02590bd
Opens a new window with list of versions in this module.
Published: Apr 24, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type APIErrorResponse struct {
Error string `json:"error"`
}
type Collection struct {
Name string `json:"name"`
Routes []Route `json:"routes"`
Groups []Group `json:"groups"`
}
type Group struct {
Name string `json:"name"`
Routes []Route `json:"routes"`
}
type Route struct {
Method string `json:"method"`
Path string `json:"path"`
StatusCode int `json:"statusCode,omitempty"`
Body any `json:"body,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.